<?php
/**
 * This file implements the Skin Area plugin.
 * It allows the administrator to define a few areas on the skin
 * which can then be customized by individual user.
 *
 * Original version @copyright (c)2006 Chiew Ruoh Tau
 *
  * b2evolution - {@link http://b2evolution.net/}
 * Released under GNU GPL License - {@link http://b2evolution.net/about/license.html}
 * @copyright (c)2003-2005 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * @package plugins
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * Skin Area Plugin
 *
  * @package plugins
 */
class skin_area_plugin extends Plugin
{
	/**
	 * Variables below MUST be overriden by plugin implementations,
	 * either in the subclass declaration or in the subclass constructor.
	 */
	var $name = 'Skin Area';
	var $code = 'evo_SkinArea';
	var $priority = 50;
	var $version = '1.8';
	var $author = 'C.R.T.';
	var $help_url = '';

	var $number_of_installs = 1;


	/**
	 * Constructor.
	 *
	 * Should set name and description in a localizable fashion.
	 * NOTE FOR PLUGIN DEVELOPERS UNFAMILIAR WITH OBJECT ORIENTED DEV:
	 * This function has the same name as the class, this makes it a "constructor".
	 * This means that this function will be called automagically by PHP when this
	 * plugin class is instantiated ("loaded").
	 */
	function skin_area_plugin()
	{
		$this->short_desc = T_('Customizable skin area');
		$this->long_desc = T_('This plugin allows for customizable skin area');
	}

	
 	/**
	 * Event handler: SkinTag
	 *
	 * @param array Associative array of parameters. Valid keys are:
	 *                - 'blog' : Blog ID
	 *                - 'area_name' : Admin defined skin area name)
	 * @return boolean did we display?
	 */
	function SkinTag( $params )
	{
		global $DB, $blog;
		$b = $blog;
		if ( isset( $params[ 'blog' ] ) && $params[ 'blog' ] )
				$b = $params[ 'blog' ];
				
		$return = false;
		if ( isset( $params[ 'return' ] ) && $params[ 'return' ] )
				$return = $params[ 'return' ];
				
		$area_name = $params[ 'area_name' ];
		$val = $DB->get_var( '
				SELECT skin_area_value
				FROM ' .$this->get_sql_table('data').'
				WHERE skin_area_name = "'.$area_name.'"
				AND skin_area_blog_ID = ' . $b );
		if ( ! $val )
		{
			$areas = $this->Settings->get( 'areas' );
			foreach( $areas as $area )
			{
				if ( $area[ 'area_name' ] == $area_name ) {
					echo $area[ 'area_value' ];
					if ( $return ) return $area[ 'area_value' ];
					return true;
				}
			}
		} 
		else {
			if ( isset( $params[ 'length' ] ) && $params[ 'length' ] )
				$val = substr( $val, 0, $params['length'] );
			if ( $return ) return $val;
			echo $val;
		}
		return true;
	}

	/**
	 * A table to store user data
	 *
	 * @return array
	 */
	function GetDbLayout()
	{
		return array(
				'CREATE TABLE '.$this->get_sql_table('data').' (
					skin_area_blog_ID INT UNSIGNED NOT NULL,
					skin_area_name VARCHAR( 50 ) NOT NULL,
					skin_area_value VARCHAR( 1024 ) NOT NULL
				)',
			);
	}
	

	/**
	 * Get the settings that the plugin can use.
	 *
	 * Those settings are transfered into a Settings member object of the plugin
	 * and can be edited in the backoffice (Settings / Plugins).
	 *
	 * @see Plugin::GetDefaultSettings()
	 * @see PluginSettings
	 * @see Plugin::PluginSettingsValidateSet()
	 * @return array
	 */
	function GetDefaultSettings()
	{
		$r = array(
			'areas' => array (
				'label' => T_( 'Skin Areas' ),
				'type' => 'array',
				'min_count' => '1',
				'entries' => array (
					'area_name' => array (
						'label' => T_( 'Area Name' ),
						'defaultvalue' => '',
						'size' => 20,
						'note' => 'Name a customizable area, e.g., banner, background etc.',
					),
					'area_value' => array (
						'label' => T_( 'Default' ),
						'defaultvalue' => '',
						'type' => 'textarea',
						'note' => 'What value to use if the user left the field empty.',
					),
					'area_note' => array (
						'label' => T_( 'Note' ),
						'defaultvalue' => '',
						'type' => 'textarea',
						'note' => 'Information that the user should know, e.g., acceptable format, etc.',
					),
				),
			),	

		);

		return $r;			
	}


	/**
	 * Register a tools tab.
	 */
	function AdminAfterMenuInit()
	{
		$this->register_menu_entry( T_('Skin Areas') );
	}

	/**
	 * Event handler: Method that gets invoked when our tab (?tab=plug_ID_X) is selected.
	 *
	 * You should catch params (GET/POST) here and do actions (no output!).
	 * Use {@link $Messages} to add messages for the user.
	 *
	 * @see Plugin::AdminTabAction()
	 */
	function AdminTabAction()
	{
		global $DB, $blog;
		
		switch( param(  'action' ) )
		{
			case 'Save':
				$DB->query( '
					DELETE FROM ' .$this->get_sql_table('data') .'
					WHERE skin_area_blog_ID = ' .$blog );
				$areas = $this->Settings->get( 'areas' );
				foreach( $areas as $area )
				{
					$area_name = $area[ 'area_name' ];
					$area_value = param( 'skin_area_'.urlencode($area_name) );
					if ( $area_value == '' ) 
					{
						$area_value = $area[ 'area_value' ];
					}

					$DB->query('INSERT INTO '.$this->get_sql_table('data').'
						VALUES ( '. $blog .', "'. $DB->escape($area_name) .'"
						, "'. $DB->escape($area_value).'" )' );
				}
				break;
		}

	}


	/**
	 * Event handler: Gets invoked when our tab is selected and should get displayed.
	 *
	 * @see Plugin::AdminTabPayload()
	 */
	function AdminTabPayload()
	{
		global $blog, $AdminUI, $DB, $Request, $Settings, $current_User;
		
		$blog = autoselect_blog( $Request->param( 'blog', 'integer', 0 ), 'blog_ismember', 1 );

		if( ! $blog  )
		{ // No blog could be selected
			return false;
		}

		echo $AdminUI->get_html_collection_list( 'blog_ismember', 1, regenerate_url() . '&blog=%d' );

		echo $this->text_from_AdminTabAction;

		$Form = & new Form(NULL,'skin_area_form');
		$Form->begin_form();
		$Form->hidden_ctrl();
		$Form->hiddens_by_key( get_memorized() );

		if ( $blog > 0 ) 
		{
			$results = $DB->get_results( '
				SELECT skin_area_name, skin_area_value
				FROM ' .$this->get_sql_table('data').'
				WHERE skin_area_blog_ID = ' . $blog );
		}
		
		$Form->begin_fieldset();
		$areas = $this->Settings->get( 'areas' );
		
		foreach( $areas as $area )
		{
			$area_value = '';
			if ( isset( $results) ) {
				foreach ( $results as $result )
				{
					if ( $result->skin_area_name == $area[ 'area_name' ] )
					{
						$area_value = $result->skin_area_value;
					}
				}
			}

			if ( $area_value == '' ) 
			{
				$area_value = $area[ 'area_value' ];
			}
			$Form->textarea( urlencode('skin_area_'.$area[ 'area_name' ]), $area_value, 3, $area[ 'area_name' ], $area[ 'area_note' ] );
		}
		$Form->end_fieldset();
		$Form->end_form( array( array('name'=>'action', 'value'=>T_('Save')) ) );
	}

}

/*
 nolog */
?>
